@@ -3,19 +3,19 @@ Admin site models for managing :class:`.ConfigurationModel` subclasses.
 """
 
 
-from django.forms import models
 from django.contrib import admin
 from django.contrib.admin import ListFilter
-from django.core.cache import caches, InvalidCacheBackendError
+from django.core.cache import InvalidCacheBackendError, caches
 from django.core.files.base import File
-from django.urls import reverse
+from django.forms import models
 from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
+from django.urls import reverse
 from django.utils.html import format_html
 from django.utils.translation import ugettext_lazy as _
 
 try:
-    cache = caches['configuration']  # pylint: disable=invalid-name
+    cache = caches['configuration']
 except InvalidCacheBackendError:
     from django.core.cache import cache
 
@@ -66,13 +66,13 @@ class ConfigurationModelAdmin(admin.ModelAdmin):
         get = request.GET.copy()
         get.update(models.model_to_dict(self.model.current()))
         request.GET = get
-        return super(ConfigurationModelAdmin, self).add_view(request, form_url, extra_context)
+        return super().add_view(request, form_url, extra_context)
 
     # Hide the save buttons in the change view
     def change_view(self, request, object_id, form_url='', extra_context=None):
         extra_context = extra_context or {}
         extra_context['readonly'] = True
-        return super(ConfigurationModelAdmin, self).change_view(
+        return super().change_view(
             request,
             object_id,
             form_url,
@@ -81,7 +81,7 @@ class ConfigurationModelAdmin(admin.ModelAdmin):
 
     def save_model(self, request, obj, form, change):
         obj.changed_by = request.user
-        super(ConfigurationModelAdmin, self).save_model(request, obj, form, change)
+        super().save_model(request, obj, form, change)
         cache.delete(obj.cache_key_name(*(getattr(obj, key_name) for key_name in obj.KEY_FIELDS)))
         cache.delete(obj.key_values_cache_key_name())
 
@@ -118,7 +118,7 @@ class ShowHistoryFilter(ListFilter):
     parameter_name = 'show_history'
 
     def __init__(self, request, params, model, model_admin):
-        super(ShowHistoryFilter, self).__init__(request, params, model, model_admin)
+        super().__init__(request, params, model, model_admin)
         if self.parameter_name in params:
             value = params.pop(self.parameter_name)
             self.used_parameters[self.parameter_name] = value
@@ -192,7 +192,7 @@ class KeyedConfigurationModelAdmin(ConfigurationModelAdmin):
                 # * user hasn't ticked the "clear" checkbox
                 # * user hasn't uploaded a new file
                 if field_value and isinstance(field_value, File):
-                    clear_checkbox_name = '{0}-clear'.format(field_name)
+                    clear_checkbox_name = f'{field_name}-clear'
                     if request.POST.get(clear_checkbox_name) != 'on':
                         request.FILES.setdefault(field_name, field_value)
                 get[field_name] = field_value
@@ -206,8 +206,8 @@ class KeyedConfigurationModelAdmin(ConfigurationModelAdmin):
     def edit_link(self, inst):
         """ Edit link for the change view """
         if not inst.is_active:
-            return u'--'
-        update_url = reverse('admin:{}_{}_add'.format(self.model._meta.app_label, self.model._meta.model_name))
-        update_url += "?source={}".format(inst.pk)
-        return format_html(u'<a href="{}">{}</a>', update_url, _('Update'))
+            return '--'
+        update_url = reverse(f'admin:{self.model._meta.app_label}_{self.model._meta.model_name}_add')
+        update_url += f"?source={inst.pk}"
+        return format_html('<a href="{}">{}</a>', update_url, _('Update'))
     edit_link.short_description = _('Update')
